.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`filters.rank`
===========================
.. automodule:: skimage.filters.rank

.. currentmodule:: skimage.filters.rank
.. autosummary::

   skimage.filters.rank.autolevel
   skimage.filters.rank.autolevel_percentile
   skimage.filters.rank.bottomhat
   skimage.filters.rank.enhance_contrast
   skimage.filters.rank.enhance_contrast_percentile
   skimage.filters.rank.entropy
   skimage.filters.rank.equalize
   skimage.filters.rank.geometric_mean
   skimage.filters.rank.gradient
   skimage.filters.rank.gradient_percentile
   skimage.filters.rank.majority
   skimage.filters.rank.maximum
   skimage.filters.rank.mean
   skimage.filters.rank.mean_bilateral
   skimage.filters.rank.mean_percentile
   skimage.filters.rank.median
   skimage.filters.rank.minimum
   skimage.filters.rank.modal
   skimage.filters.rank.noise_filter
   skimage.filters.rank.otsu
   skimage.filters.rank.percentile
   skimage.filters.rank.pop
   skimage.filters.rank.pop_bilateral
   skimage.filters.rank.pop_percentile
   skimage.filters.rank.subtract_mean
   skimage.filters.rank.subtract_mean_percentile
   skimage.filters.rank.sum
   skimage.filters.rank.sum_bilateral
   skimage.filters.rank.sum_percentile
   skimage.filters.rank.threshold
   skimage.filters.rank.threshold_percentile
   skimage.filters.rank.tophat
   skimage.filters.rank.windowed_histogram



autolevel
---------

.. autofunction:: skimage.filters.rank.autolevel


.. include:: skimage.filters.rank.autolevel.examples

autolevel_percentile
--------------------

.. autofunction:: skimage.filters.rank.autolevel_percentile


.. include:: skimage.filters.rank.autolevel_percentile.examples

bottomhat
---------

.. autofunction:: skimage.filters.rank.bottomhat


.. include:: skimage.filters.rank.bottomhat.examples

enhance_contrast
----------------

.. autofunction:: skimage.filters.rank.enhance_contrast


.. include:: skimage.filters.rank.enhance_contrast.examples

enhance_contrast_percentile
---------------------------

.. autofunction:: skimage.filters.rank.enhance_contrast_percentile


.. include:: skimage.filters.rank.enhance_contrast_percentile.examples

entropy
-------

.. autofunction:: skimage.filters.rank.entropy


.. include:: skimage.filters.rank.entropy.examples

equalize
--------

.. autofunction:: skimage.filters.rank.equalize


.. include:: skimage.filters.rank.equalize.examples

geometric_mean
--------------

.. autofunction:: skimage.filters.rank.geometric_mean


.. include:: skimage.filters.rank.geometric_mean.examples

gradient
--------

.. autofunction:: skimage.filters.rank.gradient


.. include:: skimage.filters.rank.gradient.examples

gradient_percentile
-------------------

.. autofunction:: skimage.filters.rank.gradient_percentile


.. include:: skimage.filters.rank.gradient_percentile.examples

majority
--------

.. autofunction:: skimage.filters.rank.majority


.. include:: skimage.filters.rank.majority.examples

maximum
-------

.. autofunction:: skimage.filters.rank.maximum


.. include:: skimage.filters.rank.maximum.examples

mean
----

.. autofunction:: skimage.filters.rank.mean


.. include:: skimage.filters.rank.mean.examples

mean_bilateral
--------------

.. autofunction:: skimage.filters.rank.mean_bilateral


.. include:: skimage.filters.rank.mean_bilateral.examples

mean_percentile
---------------

.. autofunction:: skimage.filters.rank.mean_percentile


.. include:: skimage.filters.rank.mean_percentile.examples

median
------

.. autofunction:: skimage.filters.rank.median


.. include:: skimage.filters.rank.median.examples

minimum
-------

.. autofunction:: skimage.filters.rank.minimum


.. include:: skimage.filters.rank.minimum.examples

modal
-----

.. autofunction:: skimage.filters.rank.modal


.. include:: skimage.filters.rank.modal.examples

noise_filter
------------

.. autofunction:: skimage.filters.rank.noise_filter


.. include:: skimage.filters.rank.noise_filter.examples

otsu
----

.. autofunction:: skimage.filters.rank.otsu


.. include:: skimage.filters.rank.otsu.examples

percentile
----------

.. autofunction:: skimage.filters.rank.percentile


.. include:: skimage.filters.rank.percentile.examples

pop
---

.. autofunction:: skimage.filters.rank.pop


.. include:: skimage.filters.rank.pop.examples

pop_bilateral
-------------

.. autofunction:: skimage.filters.rank.pop_bilateral


.. include:: skimage.filters.rank.pop_bilateral.examples

pop_percentile
--------------

.. autofunction:: skimage.filters.rank.pop_percentile


.. include:: skimage.filters.rank.pop_percentile.examples

subtract_mean
-------------

.. autofunction:: skimage.filters.rank.subtract_mean


.. include:: skimage.filters.rank.subtract_mean.examples

subtract_mean_percentile
------------------------

.. autofunction:: skimage.filters.rank.subtract_mean_percentile


.. include:: skimage.filters.rank.subtract_mean_percentile.examples

sum
---

.. autofunction:: skimage.filters.rank.sum


.. include:: skimage.filters.rank.sum.examples

sum_bilateral
-------------

.. autofunction:: skimage.filters.rank.sum_bilateral


.. include:: skimage.filters.rank.sum_bilateral.examples

sum_percentile
--------------

.. autofunction:: skimage.filters.rank.sum_percentile


.. include:: skimage.filters.rank.sum_percentile.examples

threshold
---------

.. autofunction:: skimage.filters.rank.threshold


.. include:: skimage.filters.rank.threshold.examples

threshold_percentile
--------------------

.. autofunction:: skimage.filters.rank.threshold_percentile


.. include:: skimage.filters.rank.threshold_percentile.examples

tophat
------

.. autofunction:: skimage.filters.rank.tophat


.. include:: skimage.filters.rank.tophat.examples

windowed_histogram
------------------

.. autofunction:: skimage.filters.rank.windowed_histogram


.. include:: skimage.filters.rank.windowed_histogram.examples

